:mod:`xoutil.datetime` - Basic date and time types
===================================================

.. automodule:: xoutil.datetime

.. autofunction:: new_date
.. autofunction:: new_datetime
.. autofunction:: strfdelta
.. autofunction:: strftime
.. autofunction:: get_month_first
.. autofunction:: get_month_last
.. autofunction:: is_full_month
.. autofunction:: daterange([start,] stop[, step])
